pub enum BigramQuery {
Any,
Consec(u16),
Skip1(u16),
And(Vec<BigramQuery>),
Or(Vec<BigramQuery>),
}Variants
Any
Consec(u16)
A consecutive bigram key to look up in the main index.
Skip1(u16)
A skip-1 bigram key to look up in the skip sub-index.
And(Vec<BigramQuery>)
All children must match (intersect posting lists).
Or(Vec<BigramQuery>)
At least one child must match (union posting lists).
Implementations