pub struct FilePickerOptions {
pub base_path: String,
pub enable_mmap_cache: bool,
pub enable_content_indexing: bool,
pub mode: FFFMode,
pub cache_budget: Option<ContentCacheBudget>,
pub watch: bool,
pub follow_symlinks: bool,
pub enable_fs_root_scanning: bool,
pub enable_home_dir_scanning: bool,
pub git_recency: GitRecencyConfig,
}Expand description
Options for creating a FilePicker.
Fields
base_path: Stringenable_mmap_cache: boolPre-populate mmap caches for top-frecency files after the initial scan
enable_content_indexing: boolBuild content index after the initial scan for faster content-aware filtering
mode: FFFModeMode of the picker impact the way file watcher events are handled and the scoring logic
cache_budget: Option<ContentCacheBudget>Explicit cache budget. When None, the budget is auto-computed from
the repo size after the initial scan completes.
watch: boolWhen false no background watcher will be created
follow_symlinks: boolFollow symbolic links during file indexing
enable_fs_root_scanning: boolAllow indexing the filesystem root (/)
enable_home_dir_scanning: boolAllow indexing the user’s home directory. Off by default for the same
reason as enable_fs_root_scanning
git_recency: GitRecencyConfigRanking boost for files that participated in recent commits of the current branch. Enabled with default limits unless overridden.