pub struct FrecencyTracker { /* private fields */ }Implementations
Sourceimpl FrecencyTracker
impl FrecencyTracker
pub fn new(db_path: impl AsRef<Path>, use_unsafe_no_lock: bool) -> Result<Self>
Sourcepub fn spawn_gc(
shared: SharedFrecency,
db_path: String,
use_unsafe_no_lock: bool,
) -> Result<JoinHandle<()>>
pub fn spawn_gc( shared: SharedFrecency, db_path: String, use_unsafe_no_lock: bool, ) -> Result<JoinHandle<()>>
Spawns a background thread to purge stale frecency entries and compact the database. Run it once in a while to purge old pages and keep DB file size reasonable.
It’s okay to not join this thread since it acquires locks for the db access
use fff_search::frecency::FrecencyTracker;
use fff_search::SharedFrecency;
let shared_frecency: SharedFrecency = Default::default();
let _ = FrecencyTracker::spawn_gc(shared_frecency, "/path/to/frecency_db".into(), true).ok();Sourcepub fn seconds_since_last_access(&self, path: &Path) -> Result<Option<u64>>
pub fn seconds_since_last_access(&self, path: &Path) -> Result<Option<u64>>
Returns seconds since the most recent tracked access, or None if the
file has never been tracked.
pub fn track_access(&self, path: &Path) -> Result<()>
pub fn get_access_score(&self, file_path: &Path, mode: FFFMode) -> i64