Module git

Module git 

Git status caching and repository detection utilities.

Structs

GitStatusCache
Represents a cache of a single git status query, if there is no status aka file is clear but it was specifically requested to updated the status is None otherwise contains only actual file statuses.

Functions

format_git_status
format_git_status_opt
is_modified_status