pub struct GitStatusCache(/* private fields */);Expand description
Represents a cache of a single git status query, if there is no
status aka file is clear but it was specifically requested to updated
the status is None otherwise contains only actual file statuses.
Implementations
Sourceimpl GitStatusCache
impl GitStatusCache
pub fn statuses_len(&self) -> usize
pub fn lookup_status(&self, full_path: &Path) -> Option<Status>
pub fn read_git_status( git_workdir: Option<&Path>, status_options: &mut StatusOptions, ) -> Option<Self>
pub fn git_status_for_paths<TPath: AsRef<Path> + Debug>( repo: &Repository, paths: &[TPath], ) -> Result<Self>