GrepMode

Enum GrepMode 

pub enum GrepMode {
    PlainText,
    Regex,
    Fuzzy,
}
Controls how the grep pattern is interpreted.

Variants



PlainText

Default mode: the query is treated as literal text. The pattern is searched using SIMD-accelerated memchr::memmem. Special regex characters in the query have no special meaning.



Regex

Regex mode: the query is treated as a regular expression. Uses the same grep-matcher / regex::bytes::Regex engine. Invalid regex patterns will return zero results (not an error).



Fuzzy

Fuzzy mode: the query is treated as a fuzzy needle matched against each line using neo_frizbee’s Smith-Waterman scoring. Lines are ranked by match score. Individual matched character positions are reported as highlight ranges.