fff-core - High-performance file finder library
This crate provides the core file indexing and fuzzy search functionality.
State management
All state is instance-based. Callers create their own SharedPicker /
SharedFrecency / SharedQueryTracker and pass them into
FilePicker::new_with_shared_state. Multiple independent instances can
coexist in the same process.
Re-exports
pub use file_picker::FFFMode;pub use file_picker::FuzzySearchOptions;pub use file_picker::ScanProgress;pub use grep::GrepMatch;pub use grep::GrepMode;pub use grep::GrepResult;pub use grep::GrepSearchOptions;pub use grep::has_regex_metacharacters;pub use grep::is_definition_line;pub use grep::is_import_line;pub use grep::multi_grep_search;pub use types::FileItem;pub use types::PaginationArgs;pub use types::Score;pub use types::ScoringContext;pub use types::SearchResult;
Modules
- constraints
- Constraint filtering engine for fff.
- file_
picker - frecency
- git
- grep
- High-performance grep engine for live content search.
- log
- Shared logging utilities for FFF crates.
- path_
utils - Path utility functions for file picker scoring
- query_
tracker - score
- types
Structs
- DbHealth
- Health information about a database
- FFFQuery
- Query
Parser - Main query parser - zero-cost wrapper around configuration
Enums
- Constraint
- Constraint types that can be extracted from a query
- Error
- Fuzzy
Query - Location
Traits
Functions
- parse_
location - Parse location from the end of a query string.