pub struct FilePickerOptions {
pub base_path: String,
pub enable_mmap_cache: bool,
pub enable_content_indexing: bool,
pub mode: FFFMode,
pub cache_budget: Option<ContentCacheBudget>,
pub watch: bool,
}Expand description
Options for creating a FilePicker.
Fields
base_path: Stringenable_mmap_cache: boolPre-populate mmap caches for top-frecency files after the initial scan.
enable_content_indexing: boolBuild content index after the initial scan for faster content-aware filtering.
mode: FFFModeMode of the picker impact the way file watcher events are handled and the scoring logic
cache_budget: Option<ContentCacheBudget>Explicit cache budget. When None, the budget is auto-computed from
the repo size after the initial scan completes.
watch: boolWhen false, new_with_shared_state skips the background file watcher.