Git status caching and repository detection utilities.
Structs
- GitStatus
Cache - Represents a cache of a single git status query, if there is no
status aka file is clear but it was specifically requested to updated
the status is
Noneotherwise contains only actual file statuses.