pub struct GrepResult<'a> {
pub matches: Vec<GrepMatch>,
pub files: Vec<&'a FileItem>,
pub total_files_searched: usize,
pub total_files: usize,
pub filtered_file_count: usize,
pub files_with_matches: usize,
pub next_file_offset: usize,
pub regex_fallback_error: Option<String>,
}Expand description
Result of a grep search.
Fields
matches: Vec<GrepMatch>files: Vec<&'a FileItem>Deduplicated file references for the returned matches.
total_files_searched: usizeNumber of files actually searched in this call.
total_files: usizeTotal number of indexed files (before filtering).
filtered_file_count: usizeTotal number of searchable files (after filtering out binary, too-large, etc.).
files_with_matches: usizeNumber of files that contained at least one match.
next_file_offset: usizeThe file offset to pass for the next page. 0 if there are no more files.
Callers should store this and pass it as file_offset in the next call.
regex_fallback_error: Option<String>When regex mode fails to compile the pattern, the search falls back to literal matching and this field contains the compilation error message. The UI can display this to inform the user their regex was invalid.